# DocxFill

`docxfill` lets you:

✅ Fill `{{placeholders}}` in `.docx` files with **text or images**  
✅ Fill `{{placeholders}}` in **chart files** within `.docx`  
✅ Preserve existing **comments** in `.docx` documents

## Installation

```bash
pip install docxfill